@@ -1,9 +1,14 @@
 from .preprocessor import *
+from .core import *
+from . import artefacts
+from . import utils
+from ._utils import *
 from .backbones import *
 from .detection import *
 from .recognition import *
-from . import utils
-from ._utils import *
-from .core import *
-from .export import *
 from .zoo import *
+
+from doctr.file_utils import is_tf_available
+
+if is_tf_available():
+    from .export import *
